@@ -29,7 +29,10 @@
 #'   tidy_add_contrasts()
 tidy_add_contrasts <- function(x, model = tidy_get_model(x), quiet = FALSE) {
   if (is.null(model)) {
-    stop("'model' is not provided. You need to pass it or to use 'tidy_and_attach()'.")
+    cli::cli_abort(c(
+      "{.arg model} is not provided.",
+      "You need to pass it or to use {.fn tidy_and_attach}."
+    ))
   }
 
   .attributes <- .save_attributes(x)
