@@ -42,7 +42,10 @@ tidy_select_variables <- function(
   x, include = everything(), model = tidy_get_model(x)
 ) {
   if (is.null(model)) {
-    stop("'model' is not provided. You need to pass it or to use 'tidy_and_attach()'.")
+    cli::cli_abort(c(
+      "{.arg model} is not provided.",
+      "You need to pass it or to use {.fn tidy_and_attach}."
+    ))
   }
 
   if (!"variable" %in% names(x)) {
